"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ListenerCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_ARN_FIELD_NUMBER: builtins.int
    LISTENER_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_arn: builtins.str
    listener_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_arn: builtins.str = ...,
        listener_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_arn", b"certificate_arn", "listener_arn", b"listener_arn", "resource_info", b"resource_info"]) -> None: ...

global___ListenerCertificate = ListenerCertificate

@typing_extensions.final
class ListenerAuthenticateCognitoConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AuthenticationRequestExtraParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATION_REQUEST_EXTRA_PARAMS_FIELD_NUMBER: builtins.int
    ON_UNAUTHENTICATED_REQUEST_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SESSION_COOKIE_NAME_FIELD_NUMBER: builtins.int
    SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    USER_POOL_ARN_FIELD_NUMBER: builtins.int
    USER_POOL_CLIENT_ID_FIELD_NUMBER: builtins.int
    USER_POOL_DOMAIN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authentication_request_extra_params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    on_unauthenticated_request: builtins.str
    scope: builtins.str
    session_cookie_name: builtins.str
    session_timeout: builtins.int
    user_pool_arn: builtins.str
    user_pool_client_id: builtins.str
    user_pool_domain: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authentication_request_extra_params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        on_unauthenticated_request: builtins.str = ...,
        scope: builtins.str = ...,
        session_cookie_name: builtins.str = ...,
        session_timeout: builtins.int = ...,
        user_pool_arn: builtins.str = ...,
        user_pool_client_id: builtins.str = ...,
        user_pool_domain: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_request_extra_params", b"authentication_request_extra_params", "on_unauthenticated_request", b"on_unauthenticated_request", "resource_info", b"resource_info", "scope", b"scope", "session_cookie_name", b"session_cookie_name", "session_timeout", b"session_timeout", "user_pool_arn", b"user_pool_arn", "user_pool_client_id", b"user_pool_client_id", "user_pool_domain", b"user_pool_domain"]) -> None: ...

global___ListenerAuthenticateCognitoConfig = ListenerAuthenticateCognitoConfig

@typing_extensions.final
class ListenerAuthenticateOidcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AuthenticationRequestExtraParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATION_REQUEST_EXTRA_PARAMS_FIELD_NUMBER: builtins.int
    AUTHORIZATION_ENDPOINT_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    ON_UNAUTHENTICATED_REQUEST_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SESSION_COOKIE_NAME_FIELD_NUMBER: builtins.int
    SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    TOKEN_ENDPOINT_FIELD_NUMBER: builtins.int
    USER_INFO_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authentication_request_extra_params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    authorization_endpoint: builtins.str
    client_id: builtins.str
    client_secret: builtins.str
    issuer: builtins.str
    on_unauthenticated_request: builtins.str
    scope: builtins.str
    session_cookie_name: builtins.str
    session_timeout: builtins.int
    token_endpoint: builtins.str
    user_info_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authentication_request_extra_params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        authorization_endpoint: builtins.str = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        issuer: builtins.str = ...,
        on_unauthenticated_request: builtins.str = ...,
        scope: builtins.str = ...,
        session_cookie_name: builtins.str = ...,
        session_timeout: builtins.int = ...,
        token_endpoint: builtins.str = ...,
        user_info_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_request_extra_params", b"authentication_request_extra_params", "authorization_endpoint", b"authorization_endpoint", "client_id", b"client_id", "client_secret", b"client_secret", "issuer", b"issuer", "on_unauthenticated_request", b"on_unauthenticated_request", "resource_info", b"resource_info", "scope", b"scope", "session_cookie_name", b"session_cookie_name", "session_timeout", b"session_timeout", "token_endpoint", b"token_endpoint", "user_info_endpoint", b"user_info_endpoint"]) -> None: ...

global___ListenerAuthenticateOidcConfig = ListenerAuthenticateOidcConfig

@typing_extensions.final
class ListenerFixedResponseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    MESSAGE_BODY_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content_type: builtins.str
    message_body: builtins.str
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content_type: builtins.str = ...,
        message_body: builtins.str = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "message_body", b"message_body", "resource_info", b"resource_info", "status_code", b"status_code"]) -> None: ...

global___ListenerFixedResponseConfig = ListenerFixedResponseConfig

@typing_extensions.final
class ListenerTargetGroupStickinessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_SECONDS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_seconds: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_seconds: builtins.int = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_seconds", b"duration_seconds", "enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___ListenerTargetGroupStickinessConfig = ListenerTargetGroupStickinessConfig

@typing_extensions.final
class ListenerTargetGroupTuple(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ARN_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_group_arn: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_group_arn: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_group_arn", b"target_group_arn", "weight", b"weight"]) -> None: ...

global___ListenerTargetGroupTuple = ListenerTargetGroupTuple

@typing_extensions.final
class ListenerForwardConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_GROUP_STICKINESS_CONFIG_FIELD_NUMBER: builtins.int
    TARGET_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def target_group_stickiness_config(self) -> global___ListenerTargetGroupStickinessConfig: ...
    @property
    def target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerTargetGroupTuple]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_group_stickiness_config: global___ListenerTargetGroupStickinessConfig | None = ...,
        target_groups: collections.abc.Iterable[global___ListenerTargetGroupTuple] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_group_stickiness_config", b"target_group_stickiness_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_group_stickiness_config", b"target_group_stickiness_config", "target_groups", b"target_groups"]) -> None: ...

global___ListenerForwardConfig = ListenerForwardConfig

@typing_extensions.final
class ListenerRedirectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    host: builtins.str
    path: builtins.str
    port: builtins.str
    protocol: builtins.str
    query: builtins.str
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        host: builtins.str = ...,
        path: builtins.str = ...,
        port: builtins.str = ...,
        protocol: builtins.str = ...,
        query: builtins.str = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "path", b"path", "port", b"port", "protocol", b"protocol", "query", b"query", "resource_info", b"resource_info", "status_code", b"status_code"]) -> None: ...

global___ListenerRedirectConfig = ListenerRedirectConfig

@typing_extensions.final
class ListenerAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATE_COGNITO_CONFIG_FIELD_NUMBER: builtins.int
    AUTHENTICATE_OIDC_CONFIG_FIELD_NUMBER: builtins.int
    FIXED_RESPONSE_CONFIG_FIELD_NUMBER: builtins.int
    FORWARD_CONFIG_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIG_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ARN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    AUTHENTICATION_REQUEST_EXTRA_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authenticate_cognito_config(self) -> global___ListenerAuthenticateCognitoConfig: ...
    @property
    def authenticate_oidc_config(self) -> global___ListenerAuthenticateOidcConfig: ...
    @property
    def fixed_response_config(self) -> global___ListenerFixedResponseConfig: ...
    @property
    def forward_config(self) -> global___ListenerForwardConfig: ...
    order: builtins.int
    @property
    def redirect_config(self) -> global___ListenerRedirectConfig: ...
    target_group_arn: builtins.str
    type: builtins.str
    authentication_request_extra_params: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authenticate_cognito_config: global___ListenerAuthenticateCognitoConfig | None = ...,
        authenticate_oidc_config: global___ListenerAuthenticateOidcConfig | None = ...,
        fixed_response_config: global___ListenerFixedResponseConfig | None = ...,
        forward_config: global___ListenerForwardConfig | None = ...,
        order: builtins.int = ...,
        redirect_config: global___ListenerRedirectConfig | None = ...,
        target_group_arn: builtins.str = ...,
        type: builtins.str = ...,
        authentication_request_extra_params: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authenticate_cognito_config", b"authenticate_cognito_config", "authenticate_oidc_config", b"authenticate_oidc_config", "fixed_response_config", b"fixed_response_config", "forward_config", b"forward_config", "redirect_config", b"redirect_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authenticate_cognito_config", b"authenticate_cognito_config", "authenticate_oidc_config", b"authenticate_oidc_config", "authentication_request_extra_params", b"authentication_request_extra_params", "fixed_response_config", b"fixed_response_config", "forward_config", b"forward_config", "order", b"order", "redirect_config", b"redirect_config", "resource_info", b"resource_info", "target_group_arn", b"target_group_arn", "type", b"type"]) -> None: ...

global___ListenerAction = ListenerAction

@typing_extensions.final
class Listener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALPN_POLICY_FIELD_NUMBER: builtins.int
    CERTIFICATES_FIELD_NUMBER: builtins.int
    DEFAULT_ACTIONS_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_ARN_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    LISTENER_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alpn_policy(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerCertificate]: ...
    @property
    def default_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerAction]: ...
    load_balancer_arn: builtins.str
    port: builtins.int
    protocol: builtins.str
    ssl_policy: builtins.str
    listener_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alpn_policy: collections.abc.Iterable[builtins.str] | None = ...,
        certificates: collections.abc.Iterable[global___ListenerCertificate] | None = ...,
        default_actions: collections.abc.Iterable[global___ListenerAction] | None = ...,
        load_balancer_arn: builtins.str = ...,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        ssl_policy: builtins.str = ...,
        listener_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alpn_policy", b"alpn_policy", "certificates", b"certificates", "default_actions", b"default_actions", "listener_arn", b"listener_arn", "load_balancer_arn", b"load_balancer_arn", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info", "ssl_policy", b"ssl_policy"]) -> None: ...

global___Listener = Listener

@typing_extensions.final
class ElasticLoadBalancingV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LISTENER_FIELD_NUMBER: builtins.int
    LISTENER_CERTIFICATE_FIELD_NUMBER: builtins.int
    LISTENER_RULE_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_FIELD_NUMBER: builtins.int
    TARGET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def listener(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Listener]: ...
    @property
    def listener_certificate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerCertificate]: ...
    @property
    def listener_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerRule]: ...
    @property
    def load_balancer(self) -> global___LoadBalancer: ...
    @property
    def target_group(self) -> global___TargetGroup: ...
    def __init__(
        self,
        *,
        listener: collections.abc.Iterable[global___Listener] | None = ...,
        listener_certificate: collections.abc.Iterable[global___ListenerCertificate] | None = ...,
        listener_rule: collections.abc.Iterable[global___ListenerRule] | None = ...,
        load_balancer: global___LoadBalancer | None = ...,
        target_group: global___TargetGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["load_balancer", b"load_balancer", "target_group", b"target_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["listener", b"listener", "listener_certificate", b"listener_certificate", "listener_rule", b"listener_rule", "load_balancer", b"load_balancer", "target_group", b"target_group"]) -> None: ...

global___ElasticLoadBalancingV2 = ElasticLoadBalancingV2

@typing_extensions.final
class ListenerCertificateCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_arn", b"certificate_arn", "resource_info", b"resource_info"]) -> None: ...

global___ListenerCertificateCertificate = ListenerCertificateCertificate

@typing_extensions.final
class ListenerRuleAuthenticateCognitoConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AuthenticationRequestExtraParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATION_REQUEST_EXTRA_PARAMS_FIELD_NUMBER: builtins.int
    ON_UNAUTHENTICATED_REQUEST_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SESSION_COOKIE_NAME_FIELD_NUMBER: builtins.int
    SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    USER_POOL_ARN_FIELD_NUMBER: builtins.int
    USER_POOL_CLIENT_ID_FIELD_NUMBER: builtins.int
    USER_POOL_DOMAIN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authentication_request_extra_params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    on_unauthenticated_request: builtins.str
    scope: builtins.str
    session_cookie_name: builtins.str
    session_timeout: builtins.int
    user_pool_arn: builtins.str
    user_pool_client_id: builtins.str
    user_pool_domain: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authentication_request_extra_params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        on_unauthenticated_request: builtins.str = ...,
        scope: builtins.str = ...,
        session_cookie_name: builtins.str = ...,
        session_timeout: builtins.int = ...,
        user_pool_arn: builtins.str = ...,
        user_pool_client_id: builtins.str = ...,
        user_pool_domain: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_request_extra_params", b"authentication_request_extra_params", "on_unauthenticated_request", b"on_unauthenticated_request", "resource_info", b"resource_info", "scope", b"scope", "session_cookie_name", b"session_cookie_name", "session_timeout", b"session_timeout", "user_pool_arn", b"user_pool_arn", "user_pool_client_id", b"user_pool_client_id", "user_pool_domain", b"user_pool_domain"]) -> None: ...

global___ListenerRuleAuthenticateCognitoConfig = ListenerRuleAuthenticateCognitoConfig

@typing_extensions.final
class ListenerRuleAuthenticateOidcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AuthenticationRequestExtraParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATION_REQUEST_EXTRA_PARAMS_FIELD_NUMBER: builtins.int
    AUTHORIZATION_ENDPOINT_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    ON_UNAUTHENTICATED_REQUEST_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SESSION_COOKIE_NAME_FIELD_NUMBER: builtins.int
    SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    TOKEN_ENDPOINT_FIELD_NUMBER: builtins.int
    USER_INFO_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authentication_request_extra_params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    authorization_endpoint: builtins.str
    client_id: builtins.str
    client_secret: builtins.str
    issuer: builtins.str
    on_unauthenticated_request: builtins.str
    scope: builtins.str
    session_cookie_name: builtins.str
    session_timeout: builtins.int
    token_endpoint: builtins.str
    user_info_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authentication_request_extra_params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        authorization_endpoint: builtins.str = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        issuer: builtins.str = ...,
        on_unauthenticated_request: builtins.str = ...,
        scope: builtins.str = ...,
        session_cookie_name: builtins.str = ...,
        session_timeout: builtins.int = ...,
        token_endpoint: builtins.str = ...,
        user_info_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_request_extra_params", b"authentication_request_extra_params", "authorization_endpoint", b"authorization_endpoint", "client_id", b"client_id", "client_secret", b"client_secret", "issuer", b"issuer", "on_unauthenticated_request", b"on_unauthenticated_request", "resource_info", b"resource_info", "scope", b"scope", "session_cookie_name", b"session_cookie_name", "session_timeout", b"session_timeout", "token_endpoint", b"token_endpoint", "user_info_endpoint", b"user_info_endpoint"]) -> None: ...

global___ListenerRuleAuthenticateOidcConfig = ListenerRuleAuthenticateOidcConfig

@typing_extensions.final
class ListenerRuleFixedResponseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    MESSAGE_BODY_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content_type: builtins.str
    message_body: builtins.str
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content_type: builtins.str = ...,
        message_body: builtins.str = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "message_body", b"message_body", "resource_info", b"resource_info", "status_code", b"status_code"]) -> None: ...

global___ListenerRuleFixedResponseConfig = ListenerRuleFixedResponseConfig

@typing_extensions.final
class ListenerRuleTargetGroupStickinessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_SECONDS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_seconds: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_seconds: builtins.int = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_seconds", b"duration_seconds", "enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___ListenerRuleTargetGroupStickinessConfig = ListenerRuleTargetGroupStickinessConfig

@typing_extensions.final
class ListenerRuleTargetGroupTuple(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ARN_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_group_arn: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_group_arn: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_group_arn", b"target_group_arn", "weight", b"weight"]) -> None: ...

global___ListenerRuleTargetGroupTuple = ListenerRuleTargetGroupTuple

@typing_extensions.final
class ListenerRuleForwardConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_GROUP_STICKINESS_CONFIG_FIELD_NUMBER: builtins.int
    TARGET_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def target_group_stickiness_config(self) -> global___ListenerRuleTargetGroupStickinessConfig: ...
    @property
    def target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerRuleTargetGroupTuple]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_group_stickiness_config: global___ListenerRuleTargetGroupStickinessConfig | None = ...,
        target_groups: collections.abc.Iterable[global___ListenerRuleTargetGroupTuple] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_group_stickiness_config", b"target_group_stickiness_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_group_stickiness_config", b"target_group_stickiness_config", "target_groups", b"target_groups"]) -> None: ...

global___ListenerRuleForwardConfig = ListenerRuleForwardConfig

@typing_extensions.final
class ListenerRuleRedirectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    host: builtins.str
    path: builtins.str
    port: builtins.str
    protocol: builtins.str
    query: builtins.str
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        host: builtins.str = ...,
        path: builtins.str = ...,
        port: builtins.str = ...,
        protocol: builtins.str = ...,
        query: builtins.str = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "path", b"path", "port", b"port", "protocol", b"protocol", "query", b"query", "resource_info", b"resource_info", "status_code", b"status_code"]) -> None: ...

global___ListenerRuleRedirectConfig = ListenerRuleRedirectConfig

@typing_extensions.final
class ListenerRuleAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATE_COGNITO_CONFIG_FIELD_NUMBER: builtins.int
    AUTHENTICATE_OIDC_CONFIG_FIELD_NUMBER: builtins.int
    FIXED_RESPONSE_CONFIG_FIELD_NUMBER: builtins.int
    FORWARD_CONFIG_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIG_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ARN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authenticate_cognito_config(self) -> global___ListenerRuleAuthenticateCognitoConfig: ...
    @property
    def authenticate_oidc_config(self) -> global___ListenerRuleAuthenticateOidcConfig: ...
    @property
    def fixed_response_config(self) -> global___ListenerRuleFixedResponseConfig: ...
    @property
    def forward_config(self) -> global___ListenerRuleForwardConfig: ...
    order: builtins.int
    @property
    def redirect_config(self) -> global___ListenerRuleRedirectConfig: ...
    target_group_arn: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authenticate_cognito_config: global___ListenerRuleAuthenticateCognitoConfig | None = ...,
        authenticate_oidc_config: global___ListenerRuleAuthenticateOidcConfig | None = ...,
        fixed_response_config: global___ListenerRuleFixedResponseConfig | None = ...,
        forward_config: global___ListenerRuleForwardConfig | None = ...,
        order: builtins.int = ...,
        redirect_config: global___ListenerRuleRedirectConfig | None = ...,
        target_group_arn: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authenticate_cognito_config", b"authenticate_cognito_config", "authenticate_oidc_config", b"authenticate_oidc_config", "fixed_response_config", b"fixed_response_config", "forward_config", b"forward_config", "redirect_config", b"redirect_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authenticate_cognito_config", b"authenticate_cognito_config", "authenticate_oidc_config", b"authenticate_oidc_config", "fixed_response_config", b"fixed_response_config", "forward_config", b"forward_config", "order", b"order", "redirect_config", b"redirect_config", "resource_info", b"resource_info", "target_group_arn", b"target_group_arn", "type", b"type"]) -> None: ...

global___ListenerRuleAction = ListenerRuleAction

@typing_extensions.final
class ListenerRuleHostHeaderConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___ListenerRuleHostHeaderConfig = ListenerRuleHostHeaderConfig

@typing_extensions.final
class ListenerRuleHttpHeaderConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HTTP_HEADER_NAME_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    http_header_name: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        http_header_name: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_header_name", b"http_header_name", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___ListenerRuleHttpHeaderConfig = ListenerRuleHttpHeaderConfig

@typing_extensions.final
class ListenerRuleHttpRequestMethodConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___ListenerRuleHttpRequestMethodConfig = ListenerRuleHttpRequestMethodConfig

@typing_extensions.final
class ListenerRulePathPatternConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___ListenerRulePathPatternConfig = ListenerRulePathPatternConfig

@typing_extensions.final
class ListenerRuleQueryStringKeyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ListenerRuleQueryStringKeyValue = ListenerRuleQueryStringKeyValue

@typing_extensions.final
class ListenerRuleQueryStringConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerRuleQueryStringKeyValue]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[global___ListenerRuleQueryStringKeyValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___ListenerRuleQueryStringConfig = ListenerRuleQueryStringConfig

@typing_extensions.final
class ListenerRuleSourceIpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___ListenerRuleSourceIpConfig = ListenerRuleSourceIpConfig

@typing_extensions.final
class ListenerRuleRuleCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FIELD_FIELD_NUMBER: builtins.int
    HOST_HEADER_CONFIG_FIELD_NUMBER: builtins.int
    HTTP_HEADER_CONFIG_FIELD_NUMBER: builtins.int
    HTTP_REQUEST_METHOD_CONFIG_FIELD_NUMBER: builtins.int
    PATH_PATTERN_CONFIG_FIELD_NUMBER: builtins.int
    QUERY_STRING_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_IP_CONFIG_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    field: builtins.str
    @property
    def host_header_config(self) -> global___ListenerRuleHostHeaderConfig: ...
    @property
    def http_header_config(self) -> global___ListenerRuleHttpHeaderConfig: ...
    @property
    def http_request_method_config(self) -> global___ListenerRuleHttpRequestMethodConfig: ...
    @property
    def path_pattern_config(self) -> global___ListenerRulePathPatternConfig: ...
    @property
    def query_string_config(self) -> global___ListenerRuleQueryStringConfig: ...
    @property
    def source_ip_config(self) -> global___ListenerRuleSourceIpConfig: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        field: builtins.str = ...,
        host_header_config: global___ListenerRuleHostHeaderConfig | None = ...,
        http_header_config: global___ListenerRuleHttpHeaderConfig | None = ...,
        http_request_method_config: global___ListenerRuleHttpRequestMethodConfig | None = ...,
        path_pattern_config: global___ListenerRulePathPatternConfig | None = ...,
        query_string_config: global___ListenerRuleQueryStringConfig | None = ...,
        source_ip_config: global___ListenerRuleSourceIpConfig | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["host_header_config", b"host_header_config", "http_header_config", b"http_header_config", "http_request_method_config", b"http_request_method_config", "path_pattern_config", b"path_pattern_config", "query_string_config", b"query_string_config", "resource_info", b"resource_info", "source_ip_config", b"source_ip_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field", b"field", "host_header_config", b"host_header_config", "http_header_config", b"http_header_config", "http_request_method_config", b"http_request_method_config", "path_pattern_config", b"path_pattern_config", "query_string_config", b"query_string_config", "resource_info", b"resource_info", "source_ip_config", b"source_ip_config", "values", b"values"]) -> None: ...

global___ListenerRuleRuleCondition = ListenerRuleRuleCondition

@typing_extensions.final
class ListenerRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    LISTENER_ARN_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerRuleAction]: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerRuleRuleCondition]: ...
    listener_arn: builtins.str
    priority: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        actions: collections.abc.Iterable[global___ListenerRuleAction] | None = ...,
        conditions: collections.abc.Iterable[global___ListenerRuleRuleCondition] | None = ...,
        listener_arn: builtins.str = ...,
        priority: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "conditions", b"conditions", "listener_arn", b"listener_arn", "priority", b"priority", "resource_info", b"resource_info"]) -> None: ...

global___ListenerRule = ListenerRule

@typing_extensions.final
class LoadBalancerLoadBalancerAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___LoadBalancerLoadBalancerAttribute = LoadBalancerLoadBalancerAttribute

@typing_extensions.final
class LoadBalancerSubnetMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOCATION_ID_FIELD_NUMBER: builtins.int
    PRIVATE_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    allocation_id: builtins.str
    private_ipv4_address: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allocation_id: builtins.str = ...,
        private_ipv4_address: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocation_id", b"allocation_id", "private_ipv4_address", b"private_ipv4_address", "resource_info", b"resource_info", "subnet_id", b"subnet_id"]) -> None: ...

global___LoadBalancerSubnetMapping = LoadBalancerSubnetMapping

@typing_extensions.final
class LoadBalancer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IP_ADDRESS_TYPE_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_ATTRIBUTES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SUBNET_MAPPINGS_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ip_address_type: builtins.str
    @property
    def load_balancer_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancerLoadBalancerAttribute]: ...
    name: builtins.str
    scheme: builtins.str
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnet_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancerSubnetMapping]: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ip_address_type: builtins.str = ...,
        load_balancer_attributes: collections.abc.Iterable[global___LoadBalancerLoadBalancerAttribute] | None = ...,
        name: builtins.str = ...,
        scheme: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_mappings: collections.abc.Iterable[global___LoadBalancerSubnetMapping] | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_address_type", b"ip_address_type", "load_balancer_attributes", b"load_balancer_attributes", "name", b"name", "resource_info", b"resource_info", "scheme", b"scheme", "security_groups", b"security_groups", "subnet_mappings", b"subnet_mappings", "subnets", b"subnets", "tags", b"tags", "type", b"type"]) -> None: ...

global___LoadBalancer = LoadBalancer

@typing_extensions.final
class TargetGroupMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HTTP_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    http_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        http_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_code", b"http_code", "resource_info", b"resource_info"]) -> None: ...

global___TargetGroupMatcher = TargetGroupMatcher

@typing_extensions.final
class TargetGroupTargetGroupAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___TargetGroupTargetGroupAttribute = TargetGroupTargetGroupAttribute

@typing_extensions.final
class TargetGroupTargetDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    availability_zone: builtins.str
    id: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        availability_zone: builtins.str = ...,
        id: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zone", b"availability_zone", "id", b"id", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___TargetGroupTargetDescription = TargetGroupTargetDescription

@typing_extensions.final
class TargetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_ENABLED_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_INTERVAL_SECONDS_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PATH_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PORT_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PROTOCOL_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_COUNT_FIELD_NUMBER: builtins.int
    MATCHER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ATTRIBUTES_FIELD_NUMBER: builtins.int
    TARGET_TYPE_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_COUNT_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    health_check_enabled: builtins.bool
    health_check_interval_seconds: builtins.int
    health_check_path: builtins.str
    health_check_port: builtins.str
    health_check_protocol: builtins.str
    health_check_timeout_seconds: builtins.int
    healthy_threshold_count: builtins.int
    @property
    def matcher(self) -> global___TargetGroupMatcher: ...
    name: builtins.str
    port: builtins.int
    protocol: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def target_group_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TargetGroupTargetGroupAttribute]: ...
    target_type: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TargetGroupTargetDescription]: ...
    unhealthy_threshold_count: builtins.int
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        health_check_enabled: builtins.bool = ...,
        health_check_interval_seconds: builtins.int = ...,
        health_check_path: builtins.str = ...,
        health_check_port: builtins.str = ...,
        health_check_protocol: builtins.str = ...,
        health_check_timeout_seconds: builtins.int = ...,
        healthy_threshold_count: builtins.int = ...,
        matcher: global___TargetGroupMatcher | None = ...,
        name: builtins.str = ...,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        target_group_attributes: collections.abc.Iterable[global___TargetGroupTargetGroupAttribute] | None = ...,
        target_type: builtins.str = ...,
        targets: collections.abc.Iterable[global___TargetGroupTargetDescription] | None = ...,
        unhealthy_threshold_count: builtins.int = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["matcher", b"matcher", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_enabled", b"health_check_enabled", "health_check_interval_seconds", b"health_check_interval_seconds", "health_check_path", b"health_check_path", "health_check_port", b"health_check_port", "health_check_protocol", b"health_check_protocol", "health_check_timeout_seconds", b"health_check_timeout_seconds", "healthy_threshold_count", b"healthy_threshold_count", "matcher", b"matcher", "name", b"name", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info", "tags", b"tags", "target_group_attributes", b"target_group_attributes", "target_type", b"target_type", "targets", b"targets", "unhealthy_threshold_count", b"unhealthy_threshold_count", "vpc_id", b"vpc_id"]) -> None: ...

global___TargetGroup = TargetGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_vpn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_vpn.proto\x12\x1boak9.tython.gcp.compute_vpn\x1a\x13shared/shared.proto\"<\n\x1a\x43omputeVpnGatewayXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xbb\x02\n\x11\x43omputeVpnGateway\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\ngateway_id\x18\x03 \x01(\x01\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07network\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12I\n\x08timeouts\x18\n \x01(\x0b\x32\x37.oak9.tython.gcp.compute_vpn.ComputeVpnGatewayXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\";\n\x19\x43omputeVpnTunnelXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x9c\x05\n\x10\x43omputeVpnTunnel\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65tailed_status\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x13\n\x0bike_version\x18\x05 \x01(\x01\x12\x1e\n\x16local_traffic_selector\x18\x06 \x03(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x1d\n\x15peer_external_gateway\x18\x08 \x01(\t\x12\'\n\x1fpeer_external_gateway_interface\x18\t \x01(\x01\x12\x18\n\x10peer_gcp_gateway\x18\n \x01(\t\x12\x0f\n\x07peer_ip\x18\x0b \x01(\t\x12\x0f\n\x07project\x18\x0c \x01(\t\x12\x0e\n\x06region\x18\r \x01(\t\x12\x1f\n\x17remote_traffic_selector\x18\x0e \x03(\t\x12\x0e\n\x06router\x18\x0f \x01(\t\x12\x11\n\tself_link\x18\x10 \x01(\t\x12\x15\n\rshared_secret\x18\x11 \x01(\t\x12\x1a\n\x12shared_secret_hash\x18\x12 \x01(\t\x12\x1a\n\x12target_vpn_gateway\x18\x13 \x01(\t\x12\x11\n\ttunnel_id\x18\x14 \x01(\t\x12\x13\n\x0bvpn_gateway\x18\x15 \x01(\t\x12\x1d\n\x15vpn_gateway_interface\x18\x16 \x01(\x01\x12H\n\x08timeouts\x18\x17 \x01(\x0b\x32\x36.oak9.tython.gcp.compute_vpn.ComputeVpnTunnelXTimeouts\x12\x37\n\rresource_info\x18\x18 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_vpn_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEVPNGATEWAYXTIMEOUTS._serialized_start=79
  _COMPUTEVPNGATEWAYXTIMEOUTS._serialized_end=139
  _COMPUTEVPNGATEWAY._serialized_start=142
  _COMPUTEVPNGATEWAY._serialized_end=457
  _COMPUTEVPNTUNNELXTIMEOUTS._serialized_start=459
  _COMPUTEVPNTUNNELXTIMEOUTS._serialized_end=518
  _COMPUTEVPNTUNNEL._serialized_start=521
  _COMPUTEVPNTUNNEL._serialized_end=1189
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Domain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info"]) -> None: ...

global___Domain = Domain

@typing_extensions.final
class SDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    @property
    def domain(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Domain]: ...
    def __init__(
        self,
        *,
        domain: collections.abc.Iterable[global___Domain] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain"]) -> None: ...

global___SDB = SDB



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ClouddeployDeliveryPipelineXSerialPipelineXStages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROFILES_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    @property
    def profiles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    target_id: builtins.str
    def __init__(
        self,
        *,
        profiles: collections.abc.Iterable[builtins.str] | None = ...,
        target_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["profiles", b"profiles", "target_id", b"target_id"]) -> None: ...

global___ClouddeployDeliveryPipelineXSerialPipelineXStages = ClouddeployDeliveryPipelineXSerialPipelineXStages

@typing_extensions.final
class ClouddeployDeliveryPipelineXSerialPipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STAGES_FIELD_NUMBER: builtins.int
    @property
    def stages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClouddeployDeliveryPipelineXSerialPipelineXStages]: ...
    def __init__(
        self,
        *,
        stages: collections.abc.Iterable[global___ClouddeployDeliveryPipelineXSerialPipelineXStages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stages", b"stages"]) -> None: ...

global___ClouddeployDeliveryPipelineXSerialPipeline = ClouddeployDeliveryPipelineXSerialPipeline

@typing_extensions.final
class ClouddeployDeliveryPipelineXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ClouddeployDeliveryPipelineXTimeouts = ClouddeployDeliveryPipelineXTimeouts

@typing_extensions.final
class ClouddeployDeliveryPipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ConditionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SUSPENDED_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    SERIAL_PIPELINE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def condition(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    create_time: builtins.str
    description: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    suspended: builtins.bool
    uid: builtins.str
    update_time: builtins.str
    @property
    def serial_pipeline(self) -> global___ClouddeployDeliveryPipelineXSerialPipeline: ...
    @property
    def timeouts(self) -> global___ClouddeployDeliveryPipelineXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        condition: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        suspended: builtins.bool = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        serial_pipeline: global___ClouddeployDeliveryPipelineXSerialPipeline | None = ...,
        timeouts: global___ClouddeployDeliveryPipelineXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "serial_pipeline", b"serial_pipeline", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "condition", b"condition", "create_time", b"create_time", "description", b"description", "etag", b"etag", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "serial_pipeline", b"serial_pipeline", "suspended", b"suspended", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___ClouddeployDeliveryPipeline = ClouddeployDeliveryPipeline

@typing_extensions.final
class ClouddeployTargetXAnthosCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBERSHIP_FIELD_NUMBER: builtins.int
    membership: builtins.str
    def __init__(
        self,
        *,
        membership: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["membership", b"membership"]) -> None: ...

global___ClouddeployTargetXAnthosCluster = ClouddeployTargetXAnthosCluster

@typing_extensions.final
class ClouddeployTargetXExecutionConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_STORAGE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    USAGES_FIELD_NUMBER: builtins.int
    WORKER_POOL_FIELD_NUMBER: builtins.int
    artifact_storage: builtins.str
    service_account: builtins.str
    @property
    def usages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    worker_pool: builtins.str
    def __init__(
        self,
        *,
        artifact_storage: builtins.str = ...,
        service_account: builtins.str = ...,
        usages: collections.abc.Iterable[builtins.str] | None = ...,
        worker_pool: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_storage", b"artifact_storage", "service_account", b"service_account", "usages", b"usages", "worker_pool", b"worker_pool"]) -> None: ...

global___ClouddeployTargetXExecutionConfigs = ClouddeployTargetXExecutionConfigs

@typing_extensions.final
class ClouddeployTargetXGke(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    INTERNAL_IP_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    internal_ip: builtins.bool
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
        internal_ip: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "internal_ip", b"internal_ip"]) -> None: ...

global___ClouddeployTargetXGke = ClouddeployTargetXGke

@typing_extensions.final
class ClouddeployTargetXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ClouddeployTargetXTimeouts = ClouddeployTargetXTimeouts

@typing_extensions.final
class ClouddeployTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REQUIRE_APPROVAL_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    ANTHOS_CLUSTER_FIELD_NUMBER: builtins.int
    EXECUTION_CONFIGS_FIELD_NUMBER: builtins.int
    GKE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    create_time: builtins.str
    description: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    require_approval: builtins.bool
    target_id: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def anthos_cluster(self) -> global___ClouddeployTargetXAnthosCluster: ...
    @property
    def execution_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClouddeployTargetXExecutionConfigs]: ...
    @property
    def gke(self) -> global___ClouddeployTargetXGke: ...
    @property
    def timeouts(self) -> global___ClouddeployTargetXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        require_approval: builtins.bool = ...,
        target_id: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        anthos_cluster: global___ClouddeployTargetXAnthosCluster | None = ...,
        execution_configs: collections.abc.Iterable[global___ClouddeployTargetXExecutionConfigs] | None = ...,
        gke: global___ClouddeployTargetXGke | None = ...,
        timeouts: global___ClouddeployTargetXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["anthos_cluster", b"anthos_cluster", "gke", b"gke", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "anthos_cluster", b"anthos_cluster", "create_time", b"create_time", "description", b"description", "etag", b"etag", "execution_configs", b"execution_configs", "gke", b"gke", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "require_approval", b"require_approval", "resource_info", b"resource_info", "target_id", b"target_id", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___ClouddeployTarget = ClouddeployTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ResolverEndpointIpAddressRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ip: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ip: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "resource_info", b"resource_info", "subnet_id", b"subnet_id"]) -> None: ...

global___ResolverEndpointIpAddressRequest = ResolverEndpointIpAddressRequest

@typing_extensions.final
class ResolverEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolverEndpointIpAddressRequest]: ...
    direction: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ip_addresses: collections.abc.Iterable[global___ResolverEndpointIpAddressRequest] | None = ...,
        direction: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["direction", b"direction", "ip_addresses", b"ip_addresses", "name", b"name", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "tags", b"tags"]) -> None: ...

global___ResolverEndpoint = ResolverEndpoint

@typing_extensions.final
class Route53Resolver(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOLVER_ENDPOINT_FIELD_NUMBER: builtins.int
    RESOLVER_QUERY_LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    RESOLVER_QUERY_LOGGING_CONFIG_ASSOCIATION_FIELD_NUMBER: builtins.int
    RESOLVER_RULE_FIELD_NUMBER: builtins.int
    RESOLVER_RULE_ASSOCIATION_FIELD_NUMBER: builtins.int
    @property
    def resolver_endpoint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolverEndpoint]: ...
    @property
    def resolver_query_logging_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolverQueryLoggingConfig]: ...
    @property
    def resolver_query_logging_config_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolverQueryLoggingConfigAssociation]: ...
    @property
    def resolver_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolverRule]: ...
    @property
    def resolver_rule_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolverRuleAssociation]: ...
    def __init__(
        self,
        *,
        resolver_endpoint: collections.abc.Iterable[global___ResolverEndpoint] | None = ...,
        resolver_query_logging_config: collections.abc.Iterable[global___ResolverQueryLoggingConfig] | None = ...,
        resolver_query_logging_config_association: collections.abc.Iterable[global___ResolverQueryLoggingConfigAssociation] | None = ...,
        resolver_rule: collections.abc.Iterable[global___ResolverRule] | None = ...,
        resolver_rule_association: collections.abc.Iterable[global___ResolverRuleAssociation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resolver_endpoint", b"resolver_endpoint", "resolver_query_logging_config", b"resolver_query_logging_config", "resolver_query_logging_config_association", b"resolver_query_logging_config_association", "resolver_rule", b"resolver_rule", "resolver_rule_association", b"resolver_rule_association"]) -> None: ...

global___Route53Resolver = Route53Resolver

@typing_extensions.final
class ResolverQueryLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    destination_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        destination_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ResolverQueryLoggingConfig = ResolverQueryLoggingConfig

@typing_extensions.final
class ResolverQueryLoggingConfigAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOLVER_QUERY_LOG_CONFIG_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resolver_query_log_config_id: builtins.str
    resource_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resolver_query_log_config_id: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resolver_query_log_config_id", b"resolver_query_log_config_id", "resource_id", b"resource_id", "resource_info", b"resource_info"]) -> None: ...

global___ResolverQueryLoggingConfigAssociation = ResolverQueryLoggingConfigAssociation

@typing_extensions.final
class ResolverRuleTargetAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ip: builtins.str
    port: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ip: builtins.str = ...,
        port: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip", b"ip", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___ResolverRuleTargetAddress = ResolverRuleTargetAddress

@typing_extensions.final
class ResolverRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOLVER_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    RULE_TYPE_FIELD_NUMBER: builtins.int
    TARGET_IPS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resolver_endpoint_id: builtins.str
    domain_name: builtins.str
    rule_type: builtins.str
    @property
    def target_ips(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolverRuleTargetAddress]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resolver_endpoint_id: builtins.str = ...,
        domain_name: builtins.str = ...,
        rule_type: builtins.str = ...,
        target_ips: collections.abc.Iterable[global___ResolverRuleTargetAddress] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name", b"domain_name", "name", b"name", "resolver_endpoint_id", b"resolver_endpoint_id", "resource_info", b"resource_info", "rule_type", b"rule_type", "tags", b"tags", "target_ips", b"target_ips"]) -> None: ...

global___ResolverRule = ResolverRule

@typing_extensions.final
class ResolverRuleAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    RESOLVER_RULE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    vpc_id: builtins.str
    resolver_rule_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        vpc_id: builtins.str = ...,
        resolver_rule_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resolver_rule_id", b"resolver_rule_id", "resource_info", b"resource_info", "vpc_id", b"vpc_id"]) -> None: ...

global___ResolverRuleAssociation = ResolverRuleAssociation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_dms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_dms.proto\x12\x13oak9.tython.aws.dms\x1a\x13shared/shared.proto\"\x9b\x01\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x63\x65rtificate_identifier\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_pem\x18\x03 \x01(\t\x12\x1a\n\x12\x63\x65rtificate_wallet\x18\x04 \x01(\t\"\x88\x03\n\x03\x44MS\x12\x35\n\x0b\x63\x65rtificate\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.dms.Certificate\x12/\n\x08\x65ndpoint\x18\x02 \x03(\x0b\x32\x1d.oak9.tython.aws.dms.Endpoint\x12\x42\n\x12\x65vent_subscription\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.dms.EventSubscription\x12\x46\n\x14replication_instance\x18\x04 \x03(\x0b\x32(.oak9.tython.aws.dms.ReplicationInstance\x12M\n\x18replication_subnet_group\x18\x05 \x03(\x0b\x32+.oak9.tython.aws.dms.ReplicationSubnetGroup\x12>\n\x10replication_task\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.dms.ReplicationTask\"o\n\x15\x45ndpointKafkaSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62roker\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\"\x8d\x02\n\x17\x45ndpointNeptuneSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fmax_retry_count\x18\x02 \x01(\x05\x12\x15\n\rmax_file_size\x18\x03 \x01(\x05\x12\x18\n\x10s3_bucket_folder\x18\x04 \x01(\t\x12\x1c\n\x14\x65rror_retry_duration\x18\x05 \x01(\x05\x12\x18\n\x10iam_auth_enabled\x18\x06 \x01(\x08\x12\x16\n\x0es3_bucket_name\x18\x07 \x01(\t\x12\x1f\n\x17service_access_role_arn\x18\x08 \x01(\t\"\xd1\x01\n\x1d\x45ndpointElasticsearchSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x65ndpoint_uri\x18\x02 \x01(\t\x12\"\n\x1a\x66ull_load_error_percentage\x18\x03 \x01(\x05\x12\x1c\n\x14\x65rror_retry_duration\x18\x04 \x01(\x05\x12\x1f\n\x17service_access_role_arn\x18\x05 \x01(\t\"\x89\x02\n\x12\x45ndpointS3Settings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x65xternal_table_definition\x18\x02 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x03 \x01(\t\x12\x15\n\rbucket_folder\x18\x04 \x01(\t\x12\x19\n\x11\x63sv_row_delimiter\x18\x05 \x01(\t\x12\x15\n\rcsv_delimiter\x18\x06 \x01(\t\x12\x1f\n\x17service_access_role_arn\x18\x07 \x01(\t\x12\x18\n\x10\x63ompression_type\x18\x08 \x01(\t\"t\n\x18\x45ndpointDynamoDbSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17service_access_role_arn\x18\x02 \x01(\t\"\x9f\x01\n\x17\x45ndpointKinesisSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0emessage_format\x18\x02 \x01(\t\x12\x12\n\nstream_arn\x18\x03 \x01(\t\x12\x1f\n\x17service_access_role_arn\x18\x04 \x01(\t\"\xbc\x02\n\x17\x45ndpointMongoDbSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_source\x18\x02 \x01(\t\x12\x16\n\x0e\x61uth_mechanism\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x1b\n\x13\x64ocs_to_investigate\x18\x05 \x01(\t\x12\x13\n\x0bserver_name\x18\x06 \x01(\t\x12\x0c\n\x04port\x18\x07 \x01(\x05\x12\x16\n\x0e\x65xtract_doc_id\x18\x08 \x01(\t\x12\x15\n\rdatabase_name\x18\t \x01(\t\x12\x11\n\tauth_type\x18\n \x01(\t\x12\x10\n\x08password\x18\x0b \x01(\t\x12\x15\n\rnesting_level\x18\x0c \x01(\t\"\xac\x07\n\x08\x45ndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nkms_key_id\x18\x02 \x01(\t\x12\x42\n\x0ekafka_settings\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.dms.EndpointKafkaSettings\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x15\n\rdatabase_name\x18\x05 \x01(\t\x12\x46\n\x10neptune_settings\x18\x06 \x01(\x0b\x32,.oak9.tython.aws.dms.EndpointNeptuneSettings\x12R\n\x16\x65lasticsearch_settings\x18\x07 \x01(\x0b\x32\x32.oak9.tython.aws.dms.EndpointElasticsearchSettings\x12<\n\x0bs3_settings\x18\x08 \x01(\x0b\x32\'.oak9.tython.aws.dms.EndpointS3Settings\x12\x13\n\x0b\x65ngine_name\x18\t \x01(\t\x12I\n\x12\x64ynamo_db_settings\x18\n \x01(\x0b\x32-.oak9.tython.aws.dms.EndpointDynamoDbSettings\x12\x46\n\x10kinesis_settings\x18\x0b \x01(\x0b\x32,.oak9.tython.aws.dms.EndpointKinesisSettings\x12\x10\n\x08username\x18\x0c \x01(\t\x12\x10\n\x08ssl_mode\x18\r \x01(\t\x12\x13\n\x0bserver_name\x18\x0e \x01(\t\x12#\n\x1b\x65xtra_connection_attributes\x18\x0f \x01(\t\x12\x15\n\rendpoint_type\x18\x10 \x01(\t\x12\x35\n\x04tags\x18\x11 \x03(\x0b\x32\'.oak9.tython.aws.dms.Endpoint.TagsEntry\x12\x1b\n\x13\x65ndpoint_identifier\x18\x12 \x01(\t\x12\x10\n\x08password\x18\x13 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x14 \x01(\t\x12G\n\x11mongo_db_settings\x18\x15 \x01(\x0b\x32,.oak9.tython.aws.dms.EndpointMongoDbSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x02\n\x11\x45ventSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_type\x18\x02 \x01(\t\x12\x18\n\x10\x65vent_categories\x18\x03 \x03(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x19\n\x11subscription_name\x18\x05 \x01(\t\x12\x15\n\rsns_topic_arn\x18\x06 \x01(\t\x12\x12\n\nsource_ids\x18\x07 \x03(\t\x12>\n\x04tags\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.dms.EventSubscription.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\x04\n\x13ReplicationInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1freplication_instance_identifier\x18\x02 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x03 \x01(\t\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x05 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x06 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x07 \x01(\x08\x12+\n#replication_subnet_group_identifier\x18\x08 \x01(\t\x12\x19\n\x11\x61llocated_storage\x18\t \x01(\x05\x12\x1e\n\x16vpc_security_group_ids\x18\n \x03(\t\x12#\n\x1b\x61llow_major_version_upgrade\x18\x0b \x01(\x08\x12\"\n\x1areplication_instance_class\x18\x0c \x01(\t\x12\x1b\n\x13publicly_accessible\x18\r \x01(\x08\x12\x10\n\x08multi_az\x18\x0e \x01(\x08\x12@\n\x04tags\x18\x0f \x03(\x0b\x32\x32.oak9.tython.aws.dms.ReplicationInstance.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x02\n\x16ReplicationSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12,\n$replication_subnet_group_description\x18\x02 \x01(\t\x12+\n#replication_subnet_group_identifier\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x43\n\x04tags\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.dms.ReplicationSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x03\n\x0fReplicationTask\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19replication_task_settings\x18\x02 \x01(\t\x12\x16\n\x0etable_mappings\x18\x03 \x01(\t\x12\x1a\n\x12\x63\x64\x63_start_position\x18\x04 \x01(\t\x12#\n\x1breplication_task_identifier\x18\x05 \x01(\t\x12\x19\n\x11\x63\x64\x63_stop_position\x18\x06 \x01(\t\x12\x1b\n\x13source_endpoint_arn\x18\x07 \x01(\t\x12\x16\n\x0emigration_type\x18\x08 \x01(\t\x12\x1b\n\x13target_endpoint_arn\x18\t \x01(\t\x12 \n\x18replication_instance_arn\x18\n \x01(\t\x12<\n\x04tags\x18\x0b \x03(\x0b\x32..oak9.tython.aws.dms.ReplicationTask.TagsEntry\x12\x11\n\ttask_data\x18\x0c \x01(\t\x12\x16\n\x0e\x63\x64\x63_start_time\x18\r \x01(\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_dms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINT_TAGSENTRY._options = None
  _ENDPOINT_TAGSENTRY._serialized_options = b'8\001'
  _EVENTSUBSCRIPTION_TAGSENTRY._options = None
  _EVENTSUBSCRIPTION_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONINSTANCE_TAGSENTRY._options = None
  _REPLICATIONINSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONSUBNETGROUP_TAGSENTRY._options = None
  _REPLICATIONSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONTASK_TAGSENTRY._options = None
  _REPLICATIONTASK_TAGSENTRY._serialized_options = b'8\001'
  _CERTIFICATE._serialized_start=64
  _CERTIFICATE._serialized_end=219
  _DMS._serialized_start=222
  _DMS._serialized_end=614
  _ENDPOINTKAFKASETTINGS._serialized_start=616
  _ENDPOINTKAFKASETTINGS._serialized_end=727
  _ENDPOINTNEPTUNESETTINGS._serialized_start=730
  _ENDPOINTNEPTUNESETTINGS._serialized_end=999
  _ENDPOINTELASTICSEARCHSETTINGS._serialized_start=1002
  _ENDPOINTELASTICSEARCHSETTINGS._serialized_end=1211
  _ENDPOINTS3SETTINGS._serialized_start=1214
  _ENDPOINTS3SETTINGS._serialized_end=1479
  _ENDPOINTDYNAMODBSETTINGS._serialized_start=1481
  _ENDPOINTDYNAMODBSETTINGS._serialized_end=1597
  _ENDPOINTKINESISSETTINGS._serialized_start=1600
  _ENDPOINTKINESISSETTINGS._serialized_end=1759
  _ENDPOINTMONGODBSETTINGS._serialized_start=1762
  _ENDPOINTMONGODBSETTINGS._serialized_end=2078
  _ENDPOINT._serialized_start=2081
  _ENDPOINT._serialized_end=3021
  _ENDPOINT_TAGSENTRY._serialized_start=2978
  _ENDPOINT_TAGSENTRY._serialized_end=3021
  _EVENTSUBSCRIPTION._serialized_start=3024
  _EVENTSUBSCRIPTION._serialized_end=3343
  _EVENTSUBSCRIPTION_TAGSENTRY._serialized_start=2978
  _EVENTSUBSCRIPTION_TAGSENTRY._serialized_end=3021
  _REPLICATIONINSTANCE._serialized_start=3346
  _REPLICATIONINSTANCE._serialized_end=3945
  _REPLICATIONINSTANCE_TAGSENTRY._serialized_start=2978
  _REPLICATIONINSTANCE_TAGSENTRY._serialized_end=3021
  _REPLICATIONSUBNETGROUP._serialized_start=3948
  _REPLICATIONSUBNETGROUP._serialized_end=4254
  _REPLICATIONSUBNETGROUP_TAGSENTRY._serialized_start=2978
  _REPLICATIONSUBNETGROUP_TAGSENTRY._serialized_end=3021
  _REPLICATIONTASK._serialized_start=4257
  _REPLICATIONTASK._serialized_end=4748
  _REPLICATIONTASK_TAGSENTRY._serialized_start=2978
  _REPLICATIONTASK_TAGSENTRY._serialized_end=3021
# @@protoc_insertion_point(module_scope)



import os
import ast
from typing import Iterator, AnyStr, List
import colorama
from colorama import Fore, Style

from core.bp_metadata_utils.blueprint_docstring import BlueprintDocstring
from core.bp_metadata_utils.blueprint_meta_data import BlueprintMetaData
from core.bp_metadata_utils.multiple_policies_per_file_repo import MultiplePoliciesPerFileRepo
from core.bp_metadata_utils.policy_implementation_docstring import PolicyImplementationDocstring
from core.bp_metadata_utils.policy import Policy, Validation
from core.bp_metadata_utils.python_source_file_utils import is_customer_blueprint


class CustomerBlueprintRepo(MultiplePoliciesPerFileRepo):
    """Represents Customer SaC repo."""

    def __init__(self, local_path, url="", token: str = "", skip_sync=True) -> None:
        """
        Constructs a repo for Azure Policies.
        """
        if not url and not local_path:
            raise Exception("Local Path must be provided")

        super(CustomerBlueprintRepo, self).__init__(
            url=url,
            local_path=local_path,
            skip_sync=skip_sync,
        )

    @property
    def glob_pattern(self) -> str:
        return os.path.join(
            self._local_path,
            '*.py')

    def filter(self, policy: Policy) -> bool:
        return False

    def pre_filter(self, blueprint_file_path: str) -> bool:
        return False

    def parse_policy_file(self, blueprint_path: str) -> Iterator[Policy]:
        for func in self.get_functions(blueprint_path=blueprint_path):
            docstring = ast.get_docstring(func)
            if not docstring:
                continue

            implementation_docstring = PolicyImplementationDocstring(docstring_raw=docstring)
            for implementation in implementation_docstring.implementations:
                yield implementation

    def parse_blueprint_file(self, blueprint_path: str) -> Iterator[Validation]:
        for func in self.get_functions(blueprint_path=blueprint_path):
            docstring = ast.get_docstring(func)
            if not docstring:
                continue

            implementations = []
            references = []

            func_docstring = PolicyImplementationDocstring(docstring_raw=docstring)
            for implementation in func_docstring.implementations:
                implementations.append(implementation)

            for reference in func_docstring.references:
                references.append(reference)

            yield Validation(
                references=references,
                description=func_docstring.desc,
                coverage=func_docstring.coverage,
                implements=implementations,
                name=''
            )

    @staticmethod
    def get_functions(blueprint_path: str) -> Iterator[ast.FunctionDef]:
        with open(blueprint_path) as fd:
            source = fd.read()

        module = ast.parse(source)
        implementing_class = [node for node in module.body if isinstance(node, ast.ClassDef)][0]
        # TODO: Assert that we got exactly one Class.
        return (node for node in implementing_class.body if isinstance(node, ast.FunctionDef))

    def get_blueprint_metadata(self, blueprint_path: str) -> Iterator[BlueprintMetaData]:
        with open(blueprint_path) as fd:
            source = fd.read()

        module = ast.parse(source)
        for node in module.body:
            if isinstance(node, ast.ClassDef):
                docstring = ast.get_docstring(node)
                if not docstring:
                    continue

                blueprint_docstring = BlueprintDocstring(docstring_raw=docstring)
                validations_result = []

                validations = self.parse_blueprint_file(blueprint_path)
                for validation in validations:
                    validations_result.append(validation)

                blueprint_meta_data = BlueprintMetaData(
                    name=blueprint_docstring.name,
                    desc=blueprint_docstring.desc,
                    author=blueprint_docstring.author,
                    validations=validations_result
                )

                yield blueprint_meta_data

    @property
    def blueprint_file_paths(self) -> Iterator[AnyStr]:
        paths = self.policy_file_paths
        result = []
        for path in paths:
            if is_customer_blueprint(path):
                result.append(path)
        return result

    @property
    def blueprints(self) -> List[BlueprintMetaData]:
        """
        Iterate over the blueprints and provide a summary of the blueprints
        return: A list of policies
        """
        result = []
        for blueprint_path in self.blueprint_file_paths:
            if self.pre_filter(blueprint_path):
                continue
            blueprints = self.get_blueprint_metadata(blueprint_path)
            result.extend(blueprints)

        return result

    def print_blueprint_summary(self):
        """
        Iterate over the blueprints and provide a summary of the blueprints
        return: A list of policies
        """

        blueprints = self.blueprints
        print(f"{Fore.LIGHTBLACK_EX}************************************************************")
        print(f"    {Fore.BLUE}Found {Style.BRIGHT}{len(blueprints)}{Style.NORMAL} blueprints{Style.RESET_ALL}")
        print(f"{Fore.LIGHTBLACK_EX}************************************************************{Style.RESET_ALL}")
        i = 0
        for blueprint in blueprints:
            i += 1
            print(f"\n{Style.BRIGHT}{Fore.LIGHTBLACK_EX}Blueprint #{i}{Style.NORMAL}:{Style.RESET_ALL}")
            print(f"{Style.BRIGHT}Name{Style.RESET_ALL}: {blueprint.name}")
            print(f"{Style.BRIGHT}Description{Style.RESET_ALL}: {blueprint.desc}")
            print(f"{Style.BRIGHT}Author{Style.RESET_ALL}: {blueprint.author}")
            print(f"Found {Style.BRIGHT}{len(blueprint.validations)}{Style.NORMAL} validation checks{Style.RESET_ALL}")
            j = 0
            for validation in blueprint.validations:
                j += 1
                print(f"    {Style.BRIGHT}{j}{Style.NORMAL}: {validation.description}")

            print(f"{Style.RESET_ALL}")



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeResourcePolicyXGroupPlacementPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABILITY_DOMAIN_COUNT_FIELD_NUMBER: builtins.int
    COLLOCATION_FIELD_NUMBER: builtins.int
    VM_COUNT_FIELD_NUMBER: builtins.int
    availability_domain_count: builtins.float
    collocation: builtins.str
    vm_count: builtins.float
    def __init__(
        self,
        *,
        availability_domain_count: builtins.float = ...,
        collocation: builtins.str = ...,
        vm_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_domain_count", b"availability_domain_count", "collocation", b"collocation", "vm_count", b"vm_count"]) -> None: ...

global___ComputeResourcePolicyXGroupPlacementPolicy = ComputeResourcePolicyXGroupPlacementPolicy

@typing_extensions.final
class ComputeResourcePolicyXInstanceSchedulePolicyXVmStartSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEDULE_FIELD_NUMBER: builtins.int
    schedule: builtins.str
    def __init__(
        self,
        *,
        schedule: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["schedule", b"schedule"]) -> None: ...

global___ComputeResourcePolicyXInstanceSchedulePolicyXVmStartSchedule = ComputeResourcePolicyXInstanceSchedulePolicyXVmStartSchedule

@typing_extensions.final
class ComputeResourcePolicyXInstanceSchedulePolicyXVmStopSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEDULE_FIELD_NUMBER: builtins.int
    schedule: builtins.str
    def __init__(
        self,
        *,
        schedule: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["schedule", b"schedule"]) -> None: ...

global___ComputeResourcePolicyXInstanceSchedulePolicyXVmStopSchedule = ComputeResourcePolicyXInstanceSchedulePolicyXVmStopSchedule

@typing_extensions.final
class ComputeResourcePolicyXInstanceSchedulePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    VM_START_SCHEDULE_FIELD_NUMBER: builtins.int
    VM_STOP_SCHEDULE_FIELD_NUMBER: builtins.int
    expiration_time: builtins.str
    start_time: builtins.str
    time_zone: builtins.str
    @property
    def vm_start_schedule(self) -> global___ComputeResourcePolicyXInstanceSchedulePolicyXVmStartSchedule: ...
    @property
    def vm_stop_schedule(self) -> global___ComputeResourcePolicyXInstanceSchedulePolicyXVmStopSchedule: ...
    def __init__(
        self,
        *,
        expiration_time: builtins.str = ...,
        start_time: builtins.str = ...,
        time_zone: builtins.str = ...,
        vm_start_schedule: global___ComputeResourcePolicyXInstanceSchedulePolicyXVmStartSchedule | None = ...,
        vm_stop_schedule: global___ComputeResourcePolicyXInstanceSchedulePolicyXVmStopSchedule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vm_start_schedule", b"vm_start_schedule", "vm_stop_schedule", b"vm_stop_schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "start_time", b"start_time", "time_zone", b"time_zone", "vm_start_schedule", b"vm_start_schedule", "vm_stop_schedule", b"vm_stop_schedule"]) -> None: ...

global___ComputeResourcePolicyXInstanceSchedulePolicy = ComputeResourcePolicyXInstanceSchedulePolicy

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicyXRetentionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_RETENTION_DAYS_FIELD_NUMBER: builtins.int
    ON_SOURCE_DISK_DELETE_FIELD_NUMBER: builtins.int
    max_retention_days: builtins.float
    on_source_disk_delete: builtins.str
    def __init__(
        self,
        *,
        max_retention_days: builtins.float = ...,
        on_source_disk_delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_retention_days", b"max_retention_days", "on_source_disk_delete", b"on_source_disk_delete"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicyXRetentionPolicy = ComputeResourcePolicyXSnapshotSchedulePolicyXRetentionPolicy

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXDailySchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_IN_CYCLE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    days_in_cycle: builtins.float
    start_time: builtins.str
    def __init__(
        self,
        *,
        days_in_cycle: builtins.float = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days_in_cycle", b"days_in_cycle", "start_time", b"start_time"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXDailySchedule = ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXDailySchedule

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXHourlySchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_IN_CYCLE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    hours_in_cycle: builtins.float
    start_time: builtins.str
    def __init__(
        self,
        *,
        hours_in_cycle: builtins.float = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hours_in_cycle", b"hours_in_cycle", "start_time", b"start_time"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXHourlySchedule = ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXHourlySchedule

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklyScheduleXDayOfWeeks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    day: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        day: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "start_time", b"start_time"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklyScheduleXDayOfWeeks = ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklyScheduleXDayOfWeeks

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklySchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_WEEKS_FIELD_NUMBER: builtins.int
    @property
    def day_of_weeks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklyScheduleXDayOfWeeks]: ...
    def __init__(
        self,
        *,
        day_of_weeks: collections.abc.Iterable[global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklyScheduleXDayOfWeeks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_weeks", b"day_of_weeks"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklySchedule = ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklySchedule

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicyXSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAILY_SCHEDULE_FIELD_NUMBER: builtins.int
    HOURLY_SCHEDULE_FIELD_NUMBER: builtins.int
    WEEKLY_SCHEDULE_FIELD_NUMBER: builtins.int
    @property
    def daily_schedule(self) -> global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXDailySchedule: ...
    @property
    def hourly_schedule(self) -> global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXHourlySchedule: ...
    @property
    def weekly_schedule(self) -> global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklySchedule: ...
    def __init__(
        self,
        *,
        daily_schedule: global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXDailySchedule | None = ...,
        hourly_schedule: global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXHourlySchedule | None = ...,
        weekly_schedule: global___ComputeResourcePolicyXSnapshotSchedulePolicyXScheduleXWeeklySchedule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["daily_schedule", b"daily_schedule", "hourly_schedule", b"hourly_schedule", "weekly_schedule", b"weekly_schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["daily_schedule", b"daily_schedule", "hourly_schedule", b"hourly_schedule", "weekly_schedule", b"weekly_schedule"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicyXSchedule = ComputeResourcePolicyXSnapshotSchedulePolicyXSchedule

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    GUEST_FLUSH_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STORAGE_LOCATIONS_FIELD_NUMBER: builtins.int
    guest_flush: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def storage_locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        guest_flush: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        storage_locations: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["guest_flush", b"guest_flush", "labels", b"labels", "storage_locations", b"storage_locations"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties = ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties

@typing_extensions.final
class ComputeResourcePolicyXSnapshotSchedulePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETENTION_POLICY_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    SNAPSHOT_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def retention_policy(self) -> global___ComputeResourcePolicyXSnapshotSchedulePolicyXRetentionPolicy: ...
    @property
    def schedule(self) -> global___ComputeResourcePolicyXSnapshotSchedulePolicyXSchedule: ...
    @property
    def snapshot_properties(self) -> global___ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties: ...
    def __init__(
        self,
        *,
        retention_policy: global___ComputeResourcePolicyXSnapshotSchedulePolicyXRetentionPolicy | None = ...,
        schedule: global___ComputeResourcePolicyXSnapshotSchedulePolicyXSchedule | None = ...,
        snapshot_properties: global___ComputeResourcePolicyXSnapshotSchedulePolicyXSnapshotProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["retention_policy", b"retention_policy", "schedule", b"schedule", "snapshot_properties", b"snapshot_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["retention_policy", b"retention_policy", "schedule", b"schedule", "snapshot_properties", b"snapshot_properties"]) -> None: ...

global___ComputeResourcePolicyXSnapshotSchedulePolicy = ComputeResourcePolicyXSnapshotSchedulePolicy

@typing_extensions.final
class ComputeResourcePolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeResourcePolicyXTimeouts = ComputeResourcePolicyXTimeouts

@typing_extensions.final
class ComputeResourcePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    GROUP_PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    INSTANCE_SCHEDULE_POLICY_FIELD_NUMBER: builtins.int
    SNAPSHOT_SCHEDULE_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def group_placement_policy(self) -> global___ComputeResourcePolicyXGroupPlacementPolicy: ...
    @property
    def instance_schedule_policy(self) -> global___ComputeResourcePolicyXInstanceSchedulePolicy: ...
    @property
    def snapshot_schedule_policy(self) -> global___ComputeResourcePolicyXSnapshotSchedulePolicy: ...
    @property
    def timeouts(self) -> global___ComputeResourcePolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        group_placement_policy: global___ComputeResourcePolicyXGroupPlacementPolicy | None = ...,
        instance_schedule_policy: global___ComputeResourcePolicyXInstanceSchedulePolicy | None = ...,
        snapshot_schedule_policy: global___ComputeResourcePolicyXSnapshotSchedulePolicy | None = ...,
        timeouts: global___ComputeResourcePolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["group_placement_policy", b"group_placement_policy", "instance_schedule_policy", b"instance_schedule_policy", "resource_info", b"resource_info", "snapshot_schedule_policy", b"snapshot_schedule_policy", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "group_placement_policy", b"group_placement_policy", "id", b"id", "instance_schedule_policy", b"instance_schedule_policy", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "snapshot_schedule_policy", b"snapshot_schedule_policy", "timeouts", b"timeouts"]) -> None: ...

global___ComputeResourcePolicy = ComputeResourcePolicy
